YKInterceptorResponse class

拦截器层的响应包装,封装 Dio 原生 Response,包含请求引用供响应拦截器做请求感知处理

Constructors

YKInterceptorResponse({dynamic data, int statusCode = 0, Map<String, List<String>> headers = const {}, required YKNetworkingRequest request})

Properties

data ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
final
request YKNetworkingRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited