YKNetworkException class

结构化网络异常,替代通用 Exception

Implemented types

Constructors

YKNetworkException({YKErrorType type = YKErrorType.unknown, String? message, int? statusCode, dynamic raw, RetryContext? retryContext})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
raw → dynamic
final
retryContext RetryContext?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
type YKErrorType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited