YKNetworkingConfig class
Constructors
- YKNetworkingConfig.getInstance()
-
factory
Properties
- baseUrl ↔ String
-
getter/setter pair
- cacheRequest ↔ void Function(YKNetworkingRequest request, YKNetworkingResponse response)?
-
getter/setter pair
-
commHeader
↔ Map<
String, dynamic> -
getter/setter pair
-
commParams
↔ Map<
String, dynamic> -
getter/setter pair
- dio → Dio
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- receiveTimeout ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeOut ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited