YKNetworkingRequest class

Constructors

YKNetworkingRequest({String baseUrl = '', String path = '', YKNetworkingMethod method = YKNetworkingMethod.get, Map<String, dynamic>? commheader, Map<String, dynamic>? params, dynamic progressCallBack(int count, int total)?, List<InterceptorRef> skipInterceptors = const [], CancelToken? cancelToken})

Properties

baseUrl String
getter/setter pair
cancelToken ↔ CancelToken?
getter/setter pair
commheader Map<String, dynamic>?
getter/setter pair
contentType YKNetworkingContentType?
getter/setter pair
downloadPath String?
getter/setter pair
fileLocalPath String?
getter/setter pair
fileMiniType String
getter/setter pair
fileName String
getter/setter pair
formName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
method YKNetworkingMethod
final
params Map<String, dynamic>?
getter/setter pair
path String
getter/setter pair
progressCallBack ↔ dynamic Function(int count, int total)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipInterceptors List<InterceptorRef>
getter/setter pair

Methods

download(String? downloadPath) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(String? fileLocalPath, String fileName, String fileMiniType, String formName) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited