RetryContext class

Minimal retry information carried by YKFailure to enable external retry.

Headers are intentionally excluded from this context for credential safety. However, params from the original request are shallow-copied. Sensitive data (passwords, API keys, tokens) included in request params will be exposed through this context and through YKFailure.retryContext. Strip sensitive values from request params before making the request, or override them via YKNetworking.retry's overrideParams parameter.

Constructors

RetryContext({required String baseUrl, required String path, required YKNetworkingMethod method, YKNetworkingContentType? contentType, Map<String, dynamic> params = const {}})
const
RetryContext.from(YKNetworkingRequest request)
Creates a RetryContext from a request.
factory

Properties

baseUrl String
final
contentType YKNetworkingContentType?
final
hashCode int
The hash code for this object.
no setterinherited
method YKNetworkingMethod
final
params Map<String, dynamic>
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited