YKFailure<T> class

失败结果(不含完整请求,仅 RetryContext 供重试)

Inheritance

Constructors

YKFailure({required YKNetworkException exception, int? statusCode, RetryContext? retryContext, int retryCount = 0})
const

Properties

exception YKNetworkException
final
hashCode int
The hash code for this object.
no setterinherited
retryContext RetryContext?
final
retryCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R success(YKSuccess<T> success), required R failure(YKFailure<T> failure), required R cancelled(YKCancelled<T> cancelled)}) → R
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited