YKResult<T> class
sealed
泛型网络请求结果
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({required R success(YKSuccess< T> success), required R failure(YKFailure<T> failure), required R cancelled(YKCancelled<T> cancelled)}) → R
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited