YKSuccess<T> class

成功结果

Inheritance

Constructors

YKSuccess({required T data, int statusCode = 200, required YKNetworkingRequest request})
const

Properties

data → T
final
hashCode int
The hash code for this object.
no setterinherited
request YKNetworkingRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R success(YKSuccess<T> success), required R failure(YKFailure<T> failure), required R cancelled(YKCancelled<T> cancelled)}) → R
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited