YKBaseNetworking class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
execute<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<YKResult<T>>
-
-
executeDownload<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<YKResult<T>>
-
-
executeDownloadOrThrow<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<T>
-
Throwing variant of executeDownload.
-
executeOrThrow<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<T>
-
Throwing variant of execute.
-
executeUpload<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<YKResult<T>>
-
-
executeUploadOrThrow<T>(List<YKInterceptor> interceptors, int maxRetries, YKNetworkingRequest request, {int retryCount = 0, Set<String>? retrySkipNames})
→ Future<T>
-
Throwing variant of executeUpload.