DynamicHeaderInterceptor class

每请求动态生成 header

Inheritance

Constructors

DynamicHeaderInterceptor(Future<Map<String, dynamic>?> handler(YKNetworkingRequest request))

Properties

handler Future<Map<String, dynamic>?> Function(YKNetworkingRequest request)
final
hashCode int
The hash code for this object.
no setterinherited
isIdempotent bool
no setterinherited
isProtected bool
no setterinherited
name String
no setteroverride
priority int
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type YKInterceptorType
no setteroverride

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(YKNetworkingRequest request, YKNetworkException error, YKRetryHandler retry) Future<void>
inherited
onRequest(YKNetworkingRequest request) Future<void>
override
onResponse(YKInterceptorResponse response) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited