HandleDataInterceptor class
响应数据校验/转换(原 handleData 回调)
- Inheritance
-
- Object
- YKInterceptor
- HandleDataInterceptor
Constructors
- HandleDataInterceptor({Exception? handler(YKNetworkingRequest request, YKInterceptorResponse response)?})
Properties
- handler → Exception? Function(YKNetworkingRequest request, YKInterceptorResponse response)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIdempotent → bool
-
no setterinherited
- isProtected → bool
-
no setterinherited
- name → String
-
no setteroverride
- priority → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → YKInterceptorType
-
no setteroverride
Methods
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
YKNetworkingRequest request, YKNetworkException error, YKRetryHandler retry) → Future< void> -
inherited
-
onRequest(
YKNetworkingRequest request) → Future< void> -
inherited
-
onResponse(
YKInterceptorResponse response) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited