RedirectInterceptor class
重定向拦截器:检测需要重定向的场景,抛 YKNetworkException(redirectRequired)
- Inheritance
-
- Object
- YKInterceptor
- RedirectInterceptor
Constructors
- RedirectInterceptor({bool shouldRedirect(YKNetworkException error)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIdempotent → bool
-
no setterinherited
- isProtected → bool
-
no setterinherited
- name → String
-
no setteroverride
- priority → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldRedirect → bool Function(YKNetworkException error)?
-
final
- type → YKInterceptorType
-
no setteroverride
Methods
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
YKNetworkingRequest request, YKNetworkException error, YKRetryHandler retry) → Future< void> -
override
-
onRequest(
YKNetworkingRequest request) → Future< void> -
inherited
-
onResponse(
YKInterceptorResponse response) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited