YKInterceptor class abstract
拦截器抽象基类
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIdempotent → bool
-
no setter
- isProtected → bool
-
no setter
- name → String
-
no setter
- priority → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → YKInterceptorType
-
no setter
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
YKNetworkingRequest request, YKNetworkException error, YKRetryHandler retry) → Future< void> -
onRequest(
YKNetworkingRequest request) → Future< void> -
onResponse(
YKInterceptorResponse response) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited