YKNetworkingRequest class
Constructors
-
YKNetworkingRequest({String baseUrl = "", String path = "", YKNetworkingMethod method = YKNetworkingMethod.get, Map<
String, dynamic> ? commheader, Map<String, dynamic> ? params, Exception? handleData(YKNetworkingRequest request, YKNetworkingResponse response)?, dynamic errorCallBack(YKNetworkingRequest request, Exception ex)?, dynamic progressCallBack(int count, int total)?, bool showLoading = false, dynamic showLoadingCallBack(bool show)?, bool disableDynamicHeader = false, bool disableDynamicParams = false})
Properties
- baseUrl ↔ String
-
getter/setter pair
-
commheader
↔ Map<
String, dynamic> ? -
getter/setter pair
- contentType ↔ YKNetworkingContentType?
-
getter/setter pair
- disableDynamicHeader ↔ bool
-
getter/setter pair
- disableDynamicParams ↔ bool
-
getter/setter pair
- downloadPath ↔ String?
-
getter/setter pair
- errorCallBack ↔ dynamic Function(YKNetworkingRequest request, Exception ex)?
-
getter/setter pair
- fileLocalPath ↔ String?
-
getter/setter pair
- fileMiniType ↔ String
-
getter/setter pair
- fileName ↔ String
-
getter/setter pair
- formName ↔ String
-
getter/setter pair
- handleData ↔ Exception? Function(YKNetworkingRequest request, YKNetworkingResponse response)?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → YKNetworkingMethod
-
final
-
params
↔ Map<
String, dynamic> ? -
getter/setter pair
- path ↔ String
-
getter/setter pair
- progressCallBack ↔ dynamic Function(int count, int total)?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLoading ↔ bool
-
getter/setter pair
- showLoadingCallBack ↔ dynamic Function(bool show)?
-
getter/setter pair
Methods
-
download(
String? downloadPath) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upload(
String? fileLocalPath, String fileName, String fileMiniType, String formName) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited